@@ -1,5 +1,6 @@
 import cv2
 import numpy as np
+import os
 from operator import itemgetter
 from skimage.filters import threshold_otsu
 from skimage import img_as_uint
@@ -144,7 +145,7 @@ def segment_lanes_binary(lanes_roi_backlight):
 
 
 def segment_leaf_binary(lanes_roi_binary, lanes_roi_rgb, plate_id, leaves_per_lane, predicted_lanes, destination_path,
-                        y_position, experiment, dai, file_results, report_path, report=True):
+                        y_position, experiment, dai, file_results, store_leaf_path, report_path, report=True):
     """Threshold the leaves by finding and filtering the contours of the binary lane image.
 
        :param lanes_roi_binary: The lanes of the binary image as list of tuple(image, position).
@@ -210,7 +211,8 @@ def segment_leaf_binary(lanes_roi_binary, lanes_roi_rgb, plate_id, leaves_per_la
                 if y < y_position:
                     hull = cv2.convexHull(cnt)
                     bb_leaf_rgb = image_RGB_lane[y:y + h, x:x + w]
-                    #cv2.imwrite('test' + str(leaf_id) + '.png', bb_leaf_rgb)
+                    if store_leaf_path:
+                        cv2.imwrite(os.path.join(store_leaf_path, str(experiment) + '_' + str(plate_id) + '_' + str(leaf_id) + '_01.png'), bb_leaf_rgb)
                     #cv2.imshow('', bb_leaf_rgb)
                     #cv2.waitKey(0)
 
@@ -230,14 +232,15 @@ def segment_leaf_binary(lanes_roi_binary, lanes_roi_rgb, plate_id, leaves_per_la
                         image_prediction_lane_rgb = cv2.cvtColor(image_prediction_lane, cv2.COLOR_GRAY2RGB)
                         cv2.drawContours(image_prediction_lane_rgb, [hull], -1, (0, 0, 255), 2)
 
-
+                        ''
                         # cv2.drawContours(bb_leaf_rgb, [hull], -1, (0, 0, 255), 2)
 
 
                         bb_leaf_prediction2 = image_prediction_lane_rgb[y2:y2 + h2, x2:x2 + w2]
                         #cv2.imshow('', bb_leaf_prediction2)
                         #cv2.waitKey(0)
-                        #cv2.imwrite('test2' + str(leaf_id) + '.png', bb_leaf_prediction2)
+                        if store_leaf_path:
+                            cv2.imwrite(os.path.join(store_leaf_path, str(experiment) + '_' + str(plate_id) + '_' + str(leaf_id) + '_02.png'), bb_leaf_prediction2)
 
                         # We export the results in a csv file
                         # ToDo outsource
@@ -250,7 +253,7 @@ def segment_leaf_binary(lanes_roi_binary, lanes_roi_rgb, plate_id, leaves_per_la
 
                     leaf_id += 1
 
-        cv2.imwrite(destination_path + plate_id + '_' + str(lanes_roi_rgb[lane_id][0]) + '_leaf_predict.png', image_RGB_lane)
+        cv2.imwrite(os.path.join(destination_path, plate_id + '_' + str(lanes_roi_rgb[lane_id][0]) + '_leaf_predict.png'), image_RGB_lane)
         # if report:
         #     cv2.imwrite(report_path + str(lanes_roi_rgb[lane_id][0]) + '_leaf.png', image_RGB_lane)
 
